@@ -35,6 +35,7 @@ Patterns:
 
 let compact = ref true
 let debug = Util.debug "gen"
+let times = Util.debug "times"
 let disable_compact_expr = Util.disabled "compactexpr"
 
 let set_pretty () = compact := false
@@ -859,8 +860,8 @@ and translate_expr ctx queue x e =
       | Ult, [Pv x; Pv y] ->
           let ((px, cx), queue) = access_queue queue x in
           let ((py, cy), queue) = access_queue queue y in
-          (bool (J.EBin (J.Or, J.EBin (J.Lt, cx, int 0),
-                         J.EBin (J.Lt, cy, cx))),
+          (bool (J.EBin (J.Or, J.EBin (J.Lt, cy, int 0),
+                         J.EBin (J.Lt, cx, cy))),
            or_p px py, queue)
       | WrapInt, [Pv x] ->
           let ((px, cx), queue) = access_queue queue x in
@@ -1467,6 +1468,7 @@ let list_missing l =
 
 let f ch ?(standalone=true) ((pc, blocks, _) as p) live_vars =
   let mutated_vars = Freevars.f p in
+  let t' = Util.Timer.make () in
   let ctx = Ctx.initial blocks live_vars mutated_vars in
   let p = compile_program standalone ctx pc in
   if !compact then Pretty_print.set_compact ch true;
@@ -1478,4 +1480,7 @@ let f ch ?(standalone=true) ((pc, blocks, _) as p) live_vars =
     list_missing missing
   end;
   Hashtbl.clear add_names;
-  Js_output.program ch p
+  let res = Js_output.program ch p in
+  if times () then Format.eprintf "  code gen.: %a@." Util.Timer.print t';
+  res
+
